# Private-Package

> Python CLI program to install 
> python package from private (essentially) git repository

# Usage

## Install

```bash
pip install private-package
```

## Install from (private) package repo

```bash
python -m private-package -g {your_private_package_git_repo}
```

# Features
